:mod:`art.attacks.poisoning`
============================
.. automodule:: art.attacks.poisoning

Adversarial Embedding Attack
----------------------------
.. autoclass:: PoisoningAttackAdversarialEmbedding
   :members:
   :special-members:

Backdoor Poisoning Attack
-------------------------
.. autoclass:: PoisoningAttackBackdoor
   :members:
   :special-members:

Feature Collision Attack
------------------------
.. autoclass:: FeatureCollisionAttack
   :members:
   :special-members:

Poisoning SVM Attack
--------------------
.. autoclass:: PoisoningAttackSVM
   :members:
   :special-members:
